@@ -79,8 +79,7 @@ class Activate(Save):
             if not entity_id:
                 entity = model(**relationships_in(first_activity.patch, model))
                 entity.activityIdentifier = entity_identifier
-                # TODO : to be reimplemented
-                # entity.dateCreated = first_activity.dateCreated
+                entity.dateCreated = first_activity.dateCreated
                 Save.add(entity)
                 Activate.get_db().session.flush()
                 insert_activity = entity.__insertActivity__
